import { jsx as _jsx, jsxs as _jsxs, Fragment as _Fragment } from "react/jsx-runtime";
import { useState } from 'react';
import { createRoot } from 'react-dom/client';
import { Box, Text, ToggleSwitch } from "@primer/react";
import { BoxPanel } from '@lumino/widgets';
import Jupyter from '../jupyter/Jupyter';
import Lumino from '../jupyter/lumino/Lumino';
import JupyterLabApp from "../components/app/JupyterLabApp";
import * as ipywidgetsExtension from '@jupyter-widgets/jupyterlab-manager';
import * as plotlyExtension from 'jupyterlab-plotly/lib/jupyterlab-plugin';
import * as mimePlotlyExtension from 'jupyterlab-plotly/lib/plotly-renderer';
const PATHS = [
    "ipywidgets.ipynb",
    "plotly.ipynb",
];
const PATH_INDEX = 1;
const height = "900px";
const JupyterLabHeadlessAppExample = () => {
    const [boxPanel, setBoxPanel] = useState();
    const [_, setJupyterlabAdapter] = useState();
    const [theme, setTheme] = useState('light');
    const [isOn, setIsOn] = useState(false);
    const onClick = () => {
        boxPanel?.dispose();
        if (isOn) {
            setTheme('light');
        }
        else {
            setTheme('dark');
        }
        setIsOn(!isOn);
    };
    const handleSwitchChange = (on) => {
        setIsOn(on);
    };
    const onReady = async (jupyterlabAdapter) => {
        setJupyterlabAdapter(jupyterlabAdapter);
        const jupyterlab = jupyterlabAdapter.jupyterlab;
        await jupyterlab.commands.execute('apputils:reset');
        const notebookPanel = await jupyterlab.commands.execute('docmanager:open', { path: PATHS[PATH_INDEX], factory: 'Notebook', kernel: { name: 'python3' } });
        //    const notebookTracker = jupyterlabAdapter.service("@jupyterlab/notebook-extension:tracker") as NotebookTracker;
        Object.defineProperty(jupyterlabAdapter.shell, 'currentWidget', {
            get: function () { return notebookPanel; },
            set: function (widget) { },
        });
        const boxPanel = new BoxPanel();
        boxPanel.addClass('dla-Jupyter-Notebook');
        boxPanel.spacing = 0;
        boxPanel.addWidget(notebookPanel);
        setBoxPanel(boxPanel);
    };
    return (_jsx(_Fragment, { children: _jsxs(Jupyter, { startDefaultKernel: false, disableCssLoading: true, theme: theme, children: [_jsxs(Box, { display: "flex", children: [_jsx(Box, { mr: 3, children: _jsx(Text, { as: "h2", children: "JupyterLab Headless Application" }) }), _jsxs(Box, { children: [_jsx(Box, { children: _jsx(Text, { fontSize: 2, fontWeight: "bold", id: "switch-label", display: "block", mb: 1, children: "Dark theme" }) }), _jsx(Box, { children: _jsx(ToggleSwitch, { size: "small", onClick: onClick, onChange: handleSwitchChange, checked: isOn, statusLabelPosition: "end", "aria-labelledby": "switch-label" }) })] })] }), boxPanel &&
                    _jsx("div", { style: { position: "relative" }, children: _jsx(Box, { className: "jp-LabShell", sx: {
                                '& .dla-Jupyter-Notebook': {
                                    height,
                                    maxHeight: height,
                                    width: '100%',
                                }
                            }, children: _jsx(Box, { children: _jsx(Lumino, { children: boxPanel }) }) }) }), _jsx(JupyterLabApp, { extensions: [
                        ipywidgetsExtension,
                        plotlyExtension,
                    ], mimeExtensions: [
                        mimePlotlyExtension,
                    ], theme: theme, hostId: `jupyterlab-app-${isOn}`, headless: true, onReady: onReady })] }) }));
};
const div = document.createElement('div');
document.body.appendChild(div);
const root = createRoot(div);
root.render(_jsx(JupyterLabHeadlessAppExample, {}));
//# sourceMappingURL=JupyterLabHeadlessApp.js.map