import { jsx as _jsx, jsxs as _jsxs, Fragment as _Fragment } from "react/jsx-runtime";
import { useState, useEffect } from 'react';
import { createRoot } from 'react-dom/client';
import { Box, ActionMenu, ActionList } from '@primer/react';
import { NetworkIcon, JupyterBaseIcon, JupiterIcon, ScientistIcon } from '@datalayer/icons-react';
import Jupyter from '../jupyter/Jupyter';
import Viewer from '../components/viewer/Viewer';
const visualisations = [
    {
        title: "Plotly Presentation",
        url: "https://raw.githubusercontent.com/jstac/quantecon_nyu_2016/master/lecture9/Plotly_Presentation.ipynb",
    },
    {
        title: "Matplotlib",
        url: "https://raw.githubusercontent.com/anissa111/matplotlib-tutorial/main/notebooks/01-basic-matplotlib-tutorial.ipynb",
    },
    {
        title: "Bicycle Control",
        url: "https://raw.githubusercontent.com/plotly/IPython-plotly/master/notebooks/bicycle_control/bicycle_control.ipynb",
    },
    {
        title: "IPyWidgets Example",
        url: " https://raw.githubusercontent.com/jupyter-widgets/ipywidgets/main/docs/source/examples/Widget%20Basics.ipynb",
    },
];
const dataSciences = [
    {
        title: "Fair Experiment",
        url: "https://raw.githubusercontent.com/datalayer-courses/foundations-of-data-science-with-python/main/04-probability1/fair-experiments.ipynb",
    },
    {
        title: "Text Vectorization",
        url: "https://raw.githubusercontent.com/datalayer-courses/python-text-mining-intro/main/4-text-vectorization.ipynb",
    },
    {
        title: "Survival Analysis",
        url: "https://raw.githubusercontent.com/plotly/IPython-plotly/master/notebooks/survival_analysis/survival_analysis.ipynb",
    },
];
const astronomies = [
    {
        title: "Center of Mass",
        url: "https://raw.githubusercontent.com/JuanCab/AstroInteractives/master/Interactives/Center_of_Mass.ipynb",
    },
    /*
    {
      title: "Propagation Effects",
      url: "https://raw.githubusercontent.com/ratt-ru/fundamentals_of_interferometry/master/7_Observing_Systems/7_7_propagation_effects.ipynb",
    },
    */
];
const MenuLine = (props) => {
    const { notebookExample, setNotebookExample, icon } = props;
    return (_jsxs(ActionList.Item, { onSelect: event => setNotebookExample(notebookExample), children: [_jsx(ActionList.LeadingVisual, { children: icon }), _jsx(ActionList.Description, { variant: "block", children: notebookExample.url }), notebookExample.title] }));
};
const ViewerExample = () => {
    const [notebookExample, setNotebookExample] = useState(visualisations[0]);
    const [nbformat, setNbformat] = useState();
    useEffect(() => {
        fetch(notebookExample.url)
            .then(response => {
            return response.text();
        })
            .then(nb => {
            const nbformat = nb.replaceAll('\\n', '');
            setNbformat(JSON.parse(nbformat));
        });
    }, [notebookExample]);
    return (_jsx(_Fragment, { children: _jsx(Box, { m: 3, children: _jsxs(Jupyter, { children: [_jsxs(ActionMenu, { children: [_jsx(ActionMenu.Button, { leadingVisual: () => _jsx(JupyterBaseIcon, { colored: true }), children: "Jupyter Viewer" }), _jsx(ActionMenu.Overlay, { children: _jsxs(ActionList, { showDividers: true, children: [_jsx(ActionList.Group, { title: "Visualisations", children: visualisations.map(visualisation => _jsx(MenuLine, { notebookExample: visualisation, icon: _jsx(NetworkIcon, { colored: true }), setNotebookExample: setNotebookExample })) }), "                ", _jsx(ActionList.Group, { title: "Data Science", children: dataSciences.map(dataScience => _jsx(MenuLine, { notebookExample: dataScience, icon: _jsx(ScientistIcon, { colored: true }), setNotebookExample: setNotebookExample })) }), _jsx(ActionList.Group, { title: "Astronomy", children: astronomies.map(astronomy => _jsx(MenuLine, { notebookExample: astronomy, icon: _jsx(JupiterIcon, { colored: true }), setNotebookExample: setNotebookExample })) })] }) })] }), nbformat && _jsx(Viewer, { nbformat: nbformat, outputs: true })] }) }) }));
};
const div = document.createElement('div');
document.body.appendChild(div);
const root = createRoot(div);
root.render(_jsx(ViewerExample, {}));
//# sourceMappingURL=Viewer.js.map